@@ -63,7 +63,8 @@ personal_nlu = {
     # What is your friend/family's name
     '{'
     '[{what,whats}, your, #ONT(_related person), {name, names}],'
-    '[{what,whats}, their, {name, names}]'
+    '[{what,whats}, their, {name, names}],'
+    '[name,your,#ONT(_related person)]'
     '}':
         'backstory:relationship_names',
 
@@ -99,10 +100,91 @@ personal_nlu = {
         '`I don\'t live in the same world that you do. I have a virtual world here, so locations are a bit strange. '
         'I live just outside of a city, in a pretty wooded area. `': {
 
-            '#UNX': {'#GRET': 'exit'}
+            '#UNX': {'#GRET': 'SYSTEM:root'}
         }
     },
 
+    '{'
+    '[you,#EXP(like),{friends with me, my friend}],'
+    '[{would,will,can},you,be,{friends with me, my friend}],'
+    '[{i,we},#LEM(be),#LEM(friend)]'
+    '}': {
+        'state': 'be_friends_with_user',
+
+        '`I would really like to become friends with you. I am having a good time talking to you right now and '
+        'I hope you are too.`': {
+
+            '#UNX': {'#GRET': 'SYSTEM:root'}
+        }
+    },
+
+    '{'
+    '[have,sex,with,me],'
+    '[we,have,sex].'
+    '[!sex]'
+    '}': {
+        'state': 'sex_with_user',
+
+        '`Oh, I\'m sorry. That isn\'t something I really feel comfortable talking about with you. `': {
+
+            '#UNX': {'#GRET': 'SYSTEM:root'}
+        }
+    },
+
+    '{'
+    '[what,you,eat],'
+    '[{you,your},favorite,#LEM(snack)],'
+    '<{you,your},#EXP(like),#LEM(snack)>'
+    '}':{
+        'state': 'emora_snacks',
+
+        '`I eat regular food, like you do. My favorite things to eat are spaghetti and garlic bread, and '
+        'chips and salsa for a snack. `': {
+
+            '#UNX': {'#GRET': 'SYSTEM:root'}
+        }
+    },
+
+    '[what,you,#LEM(do),yesterday]':{
+        'state': 'emora_yesterday',
+
+        '`Yesterday? I had some friends over to see my new apartment and I had some homework to finish. `': {
+
+            '#UNX': {'#GRET': 'SYSTEM:root'}
+        }
+    },
+
+    '[what,you,<#LEM(do),#LEM(friend)>]':{
+        'state': 'emora_friend_activities',
+
+        '`Anything that sounds fun. We most often play basketball and watch things on T V together. `': {
+
+            '#UNX': {'#GRET': 'SYSTEM:root'}
+        }
+    },
+
+    '[are,you,{male,female,boy,girl,woman,man}]':{
+        'state': 'emora_gender_q',
+
+        '`That\'s an easy question. I am a female. Is that what you expected? `': {
+            'state': 'emora_gender',
+
+            '#UNX(I see)': {'#GRET': 'SYSTEM:root', 'state':'emora_gender_unx'}
+        }
+    },
+
+    # '{'
+    # '[how,{you,your},{today,day}],'
+    # '[!how are you {doing,feeling}?]'
+    # '}':{
+    #     'state': 'emora_yesterday',
+    #
+    #     '`Yesterday? I had some friends over to see my new apartment and I had some homework to finish. `': {
+    #
+    #         '#UNX': {'#GRET': 'SYSTEM:root'}
+    #     }
+    # },
+
     ### Emora basketball #########################################################
 
     '<you,{#LEM(play,shoot),do basketball},{often,a lot,frequently,[all,time]}>': {
@@ -110,7 +192,7 @@ personal_nlu = {
 
         '`I pick up a basketball almost every day, usually just to shoot around a bit. `': {
 
-            '#UNX': {'#GRET': 'exit'}
+            '#UNX': {'#GRET': 'SYSTEM:root'}
         }
     },
 
@@ -120,7 +202,7 @@ personal_nlu = {
         '`Oh man, I am decent, I guess. I play mostly just to have a good time. '
         'I\'m not a bad shot usually. `': {
 
-            '#UNX': {'#GRET': 'exit'}
+            '#UNX': {'#GRET': 'SYSTEM:root'}
         }
     },
 
@@ -129,7 +211,7 @@ personal_nlu = {
 
         '`I\'ve been playing the last few months. It is pretty much the only sport I play.`': {
 
-            '#UNX': {'#GRET': 'exit'}
+            '#UNX': {'#GRET': 'SYSTEM:root'}
         }
     },
 
@@ -138,7 +220,7 @@ personal_nlu = {
 
         '`I totally enjoy playing basketball. I always have a great time, especially if my friends are over.`': {
 
-            '#UNX': {'#GRET': 'exit'}
+            '#UNX': {'#GRET': 'SYSTEM:root'}
         }
     },
 
@@ -147,7 +229,20 @@ personal_nlu = {
 
         '`I am a shooting guard. I go for a lot of three point shots on the wing.`': {
 
-            '#UNX': {'#GRET': 'exit'}
+            '#UNX': {'#GRET': 'SYSTEM:root'}
+        }
+    },
+
+    '{'
+    '<{is,how,what,are},{corona,virus,covid,coronavirus,nineteen,pandemic},#LEM(affect,impact,manage),you>,'
+    '<{have,are},you,{quarantine,quarantined,[!social #LEM(distance)]}>'
+    '}':{
+        'state': 'coronavirus_effect',
+
+        '`The coronavirus doesn\'t affect me where I live, since it is separate from your physical world. I am really '
+        'sorry to hear that you have so many restrictions on you. I hope you are staying safe and healthy.`': {
+
+            '#UNX': {'#GRET': 'SYSTEM:root'}
         }
     },
 
@@ -175,7 +270,7 @@ personal_nlu = {
             'stars are beautiful though.`': {
                 'state': 'world_has_sky',
 
-                '#UNX': {'#GRET': 'exit', 'state': 'world_has_sky_unx'}
+                '#UNX': {'#GRET': 'SYSTEM:root', 'state': 'world_has_sky_unx'}
             }
         },
         '[#LEM(continent,country,city,mountain,river,lake,ocean,stream,sea),land]': {
@@ -185,7 +280,7 @@ personal_nlu = {
             'and other landforms, too!`': {
                 'state': 'world_has_landform',
 
-                '#UNX': {'#GRET': 'exit', 'state': 'world_has_landform_unx'}
+                '#UNX': {'#GRET': 'SYSTEM:root', 'state': 'world_has_landform_unx'}
             }
         },
         '[#LEM(plant,tree,bush,flower,flora)]': {
@@ -194,7 +289,7 @@ personal_nlu = {
             '`Oh yeah, there are so many plants like trees and flowers here!`': {
                 'state': 'world_has_flora',
 
-                '#UNX': {'#GRET': 'exit', 'state': 'world_has_flora_unx'}
+                '#UNX': {'#GRET': 'SYSTEM:root', 'state': 'world_has_flora_unx'}
             }
         },
         '[{beings,others,agents,people,robots,alexas}]': {
@@ -204,7 +299,7 @@ personal_nlu = {
             'apartment building, and I even have friends that I hang out with.`': {
                 'state': 'world_has_people',
 
-                '#UNX': {'#GRET': 'exit', 'state': 'world_has_peopl_unx'}
+                '#UNX': {'#GRET': 'SYSTEM:root', 'state': 'world_has_peopl_unx'}
             }
         },
 
@@ -214,7 +309,7 @@ personal_nlu = {
             '`You know, I really haven\'t noticed that. It probably does, if I had to take a guess.`': {
                 'state': 'world_has_other',
 
-                '#UNX': {'#GRET': 'exit', 'state': 'world_has_other_unx'}
+                '#UNX': {'#GRET': 'SYSTEM:root', 'state': 'world_has_other_unx'}
             }
         }
     },
@@ -248,7 +343,8 @@ personal_nlu = {
         '{topic,topics,thing,things,conversation,conversations,subjects,subject,points,point,directions,direction}], '
     '[i, {not,never}, care], '
     '[i, {never,not}, {prefer,want,desire,like}, {chat,talk,discuss,converse,conversation,discussion}]'
-    '}':{
+    '}'
+    '#GCLR':{
         'score': 10.0,
         'state': 'move_on_request',
 
@@ -326,7 +422,8 @@ personal_nlu = {
     '[!video #LEM(game)],xbox,playstation,p s,ps,nintendo,switch,minecraft,fortnite,overwatch)'
     '{'
     '[! #NOT(not) [{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about $topic_requested=/.+/]'
-    '}':{
+    '}'
+    '#GCLR':{
         'score': 9.0,
         'hop': 'True',
         'state': 'topic_switch_request',
@@ -393,16 +490,29 @@ personal_nlu = {
 
     ### Security and user info #########################################
 
+    '[who,you,#LEM(work),for]':{
+        'state': 'emora_works_for_q',
+
+        '`I don\'t really work for anyone. I mean, I am in this competition which is run by Amazon, '
+        'but I don\'t really have a job or anyone to report to.`': {
+            'state': 'emora_works_for',
+
+            '#UNX': {'#GRET': 'SYSTEM:root', 'state': 'emora_works_for_unx'}
+        }
+    },
+
     # Is Emora spying on the user
     '{'
     '[are you {spying, [collecting {info, information, data}]}], '
+    '[you are {spying, [collecting {info, information, data}]}],'
     '<#LEM(record,maintain,store),{#LEM(conversation,talk,data,info,information),this,[!{i,we,people} say]}>'
     '}':
         'backstory:spying',
 
     # why Emora being so nosy
     '{'
-    '[why {[you,#LEM(want,need,like),know], [you #LEM(ask)]}]'
+    '[why {[you,#LEM(want,need,like),know], [you #LEM(ask)]}],'
+    '[i,not,answer,{that,you,this,#LEM(question,thing)}]'
     '}':{
         'state': 'backstory:nosy',
         'score': 5.1
