@@ -7,6 +7,8 @@ from emora._flows.house import house
 from emora._flows.reading import reading
 from emora._flows.world import world
 from emora._flows.work import work
+from emora._flows.sibling import sibling
+from emora._flows.relationships import relationships
 
 from _globals import PATHDIR
 from emora_stdm import CompositeDialogueFlow,DialogueFlow
@@ -22,7 +24,9 @@ flow_components = {
     'competition': competition,
     'backstory': backstory,
     'world': world,
-    'worklife': work
+    'worklife': work,
+    'sibling': sibling,
+    'relationships': relationships
 }
 
 cdf = CompositeDialogueFlow('root', 'recovery_from_failure', 'recovery_from_failure', DialogueFlow.Speaker.USER)
@@ -34,8 +38,11 @@ for namespace, component in flow_components.items():
     cdf.add_component(component, namespace)
 
 cdf.add_system_transition('root', 'house:start', '', score=1.5)
-cdf.add_system_transition('root', 'worklife:start', '', score=2.0)
-cdf.add_system_transition('root', 'school_new:start', '', score=3.0)
+cdf.add_system_transition('root', 'worklife:start', '', score=3.0)
+cdf.add_system_transition('root', 'school_new:start', '', score=4.0)
+cdf.add_system_transition('root', 'sibling:start', '', score=1.5)
+cdf.add_system_transition('root', 'relationships:dating', '', score=2.0)
+cdf.add_system_transition('root', 'relationships:marriage', '', score=2.0)
 
 cdf.add_system_transition('life_opening', 'house:start', '')
 cdf.add_system_transition('life_opening', 'worklife:start', '')
@@ -50,4 +57,4 @@ for component in cdf.components():
 
 if __name__ == '__main__':
     #cdf.precache_transitions()
-    cdf.run(debugging=True)
\ No newline at end of file
+    cdf.run(debugging=False)
\ No newline at end of file
