@@ -68,7 +68,7 @@ system = {
             'something other than me for once.`'
             '#GSRET(reciprocity)':{
 
-                '#UNX(So yeah.)': {
+                '#UNX(So yeah)': {
                     'state': 'its_been_cool',
 
                     '` That\'s been cool to see my cousin and her husband '
