@@ -12,12 +12,21 @@ system = {
     'state': 'start',
     'enter': '#GATE #GCOM(house) #GOAL(house) #IF($life_in=True) #ANY($is_student=False,$is_student=None)',
 
-    '`Do you want to know something? I can\'t stop thinking about how good my day was yesterday. '
+    '`Do you want to know something? I can\'t stop thinking about my day yesterday. '
     'My friends came over to my new apartment for the first time and it was so much fun.`'
     '#GSRET(user_living) #SET($introduced_virtual=False)':{
         'state': 'share_new_house',
         'score': 2.0,
 
+        '{[why],[what,{[you,do],happened,good}]}':{
+            'state': 'friends_at_apartment',
+
+            '`It was just nice to show them my apartment a bit. We also talked and played some basketball together. '
+            'There is a community basketball court in the complex. So, `': 'user_living'
+
+        },
+
+
         '#INTERESTED':{
             'state': 'more_about_house',
 
@@ -63,6 +72,40 @@ system = {
         #     'score': 0.9
         # },
 
+        '{'
+        '[{how,what},it,{like,have}],'
+        '[[!tell me {more,about it,more about it,more about that}]],'
+        '[how,{is,feel},it],'
+        '[what,you,think,{of,about},it]'
+        '}': {
+            'state': 'tell_more_apartment_local',
+            'score': 10.1,
+
+            '`It\'s a pretty good place for me, honestly. '
+            'It is just a one-bedroom apartment, but it has a lot more space and I get a lot of light through my '
+            'windows. I also have a balcony which is nice.`'
+            '#GSRET(user_living)': {
+
+                '#UNX': 'user_living'
+            }
+        },
+
+        '{'
+        '[{how,what},experience,{like,have}],'
+        '[[!tell me {about that experience, more about that experience}]],'
+        '[how,{#LEM(is),feel},experience],'
+        '[what,you,think,{of,about},experience]'
+        '}': {
+            'state': 'tell_more_experience',
+            'score':10.2,
+
+            '`I love having my friends over. We hang out a lot and talk and do fun things together. `'
+            '#GSRET(user_living)': {
+
+                '#UNX': 'user_living'
+            }
+        },
+
         '#UNX': {
             'state': 'user_living'
         }
@@ -78,7 +121,11 @@ user_living = {
         '{#AGREE, [{i do, i like, not bad, not too bad}]}'
         '#SET($user_likes_home=True)':{
 
-            '`That\'s great! What do you like about it?`': {
+            '#DEFAULT `So, what do you like the most about your home?`': 'user_best_home',
+
+            '`That\'s great! What do you like about it?`'
+            '#GATE': {
+                'state': 'user_best_home',
 
                 '#IDK': {
                     'state': 'user_likes_house_idk',
@@ -185,7 +232,11 @@ user_living = {
         '[{#DISAGREE, i do not, #ONT(_negative adj)}]'
         '#SET($user_likes_home=False)':{
 
-            '`That\'s hard. What bothers you the most about it?`': {
+            '#DEFAULT `So, what do you like the least about your home?`': 'user_worst_home',
+
+            '`That\'s hard. What bothers you the most about it?`'
+            '#GATE': {
+                'state': 'user_worst_home',
 
                 '#IDK': {
                     'state': 'user_hates_house_idk',
@@ -290,6 +341,16 @@ user_living = {
                     '`It\'s tough to be in a place that doesn\'t feel like home. I know I hated the last place I was living.`'
                     '#GSRET(school_proximity)':{
 
+                        '[why]': {
+
+                            '`It was just really, really small and dark. I couldn\'t even have people over because '
+                            'of the small space. `'
+                            '#GSRET(school_proximity)': {
+
+                                '#UNX': 'school_proximity'
+                            }
+                        },
+
                         '#UNX': 'school_proximity'
                     }
                 }
@@ -330,9 +391,11 @@ school_proximity = {
                 '`My old apartment was forty five minutes away from where I go to school, it was the worst.`'
                 '#GSRET(live_with)': {
 
-                    '[{fifty, hour, eighty, ninety}]': {
+                    '[{fifty, #LEM(hour), sixty, seventy, eighty, ninety}]': {
 
-                        '`Wow how do you even survive?`': {
+                        '`Wow, and I thought my commute time was bad before. I cannot believe you survive that. '
+                        'I feel for you. `'
+                        '#GSRET(live_with)': {
 
                             '#UNX': 'live_with'
                         }
@@ -349,6 +412,17 @@ school_proximity = {
                             'live_with'
                     },
 
+                    '[{what,why},you,{dislike,hate,#EXP(like)},'
+                    '{[{old,previous,past,last,used,before,that},{#LEM(live),apartment,house,home,place}],it}]': {
+                        'state': 'like_previous_place_local',
+
+                        '`Something was always broken that I had to deal with and it was very small and dark, too. '
+                        'I never could imagine living there again.`': {
+
+                            '#UNX': {'#GRET': 'exit'}
+                        }
+                    },
+
                     '#UNX': 'live_with'
                 }
             }
@@ -397,7 +471,7 @@ entertain_people = {
             }
         },
 
-        '[{coronavirus,corona,pandemic,#LEM(isolate,distance,quarantine),'
+        '[{coronavirus,corona,virus,pandemic,#LEM(isolate,distance,quarantine),'
         'shelter in place,stay at home,lockdown,[!social #LEM(distance)]}]': {
             'state': 'hosting_coronavirus_restrictions',
             'score': 10.1,
@@ -473,7 +547,9 @@ live_with = {
         '#AGREE #GATE':{
             'state': 'lives_with_y',
 
-            '`Oh, that\'s cool! Who do you live with then?`': 'live_with_response'
+            '`Oh, that\'s cool! Who do you live with then?`'
+            '#GSRET(exit)':
+                'live_with_response'
 
         },
 
@@ -500,7 +576,7 @@ live_with = {
             }
         },
 
-        '#UNX(Okay. )': 'exit'
+        '#UNX(Okay)': 'exit'
     }
 }
 
@@ -516,7 +592,10 @@ exit = {
 user = {
     'state': 'user',
 
-    '[where, {you,your}, <{old,previous,past,last,used,before}, {#LEM(live),house,home,place}>]':{
+    '{'
+    '[where, {you,your,the}, <{old,previous,past,last,used,before}, {#LEM(live),house,home,place}>],'
+    '[where,were,you,#LEM(live,stay)]'
+    '}':{
         'state': 'previous_place',
 
         '`It was just this small apartment, nothing special.`': {
@@ -525,10 +604,10 @@ user = {
         }
     },
 
-    '<you,#EXP(like),{old,previous,past,last,used,before},{#LEM(live),house,home,place}>': {
+    '<you,{dislike,hate,#EXP(like)},{old,previous,past,last,used,before},{#LEM(live),house,home,place}>': {
         'state': 'like_previous_place',
 
-        '`Oh, gosh, not at all. It was the absolute worst, something was always broken that I had to deal with. '
+        '`Oh, gosh, I did not like it at all. It was the absolute worst, something was always broken that I had to deal with. '
         'I never could imagine living there again.`': {
 
             '#UNX': {'#GRET': 'exit'}
@@ -550,8 +629,65 @@ user = {
 
             '#UNX': {'#GRET': 'exit'}
         }
-    }
+    },
 
+    '{'
+    '[what,your,{house,home,apartment,place},{like,have}],'
+    '[tell me {about,more},your,{house,home,apartment,place}],'
+    '[how,{is,feel},your,{house,home,apartment,place}],'
+    '[what,you,think,your,{house,home,apartment,place}]'
+    '}': {
+        'state': 'tell_more_apartment',
+
+        '`It\'s a pretty good place for me, honestly. '
+        'It is just a one-bedroom apartment, but it has a lot more space and I get a lot of light through my '
+        'windows. I also have a balcony which is nice.`': {
+
+            '#UNX': {'#GRET': 'exit'}
+        }
+    },
+
+    '<{you,your},{rooms,size,big,small,large},{house,home,apartment,place}>': {
+        'state': 'apartment_size',
+
+        '`It has a kitchen, living room, bathroom, bedroom, and laundry room. That\'s about it, nothing too big. `': {
+
+            '#UNX': {'#GRET': 'exit'}
+        }
+    },
+
+    '<what,in,your,{house,home,apartment,place}>': {
+        'state': 'apartment_contents',
+
+        '`It has a kitchen, living room, bathroom, bedroom, and laundry room. And obviously some furniture like a tv and '
+        'couch and stuff. Just normal things. `': {
+
+            '#UNX': {'#GRET': 'exit'}
+        }
+    },
+
+    '<why,#LEM(friend,people),{come,over,visit}>': {
+        'state': 'why_friends_come',
+
+        '`It was like a house-warming party, so they could see my new place. Plus we just like to hang out all the time. `': {
+
+            '#UNX': {'#GRET': 'exit'}
+        }
+    },
+
+    '{'
+    '<{you,your},{neighborhood,community,neighbors,area,location},{good,fun,safe}>,'
+    '<you,feel,{welcome,belong,belonging}>,'
+    '[what,you,like,{neighborhood,community,neighbors,area,location}]'
+    '}':{
+        'state': 'apartment_neighborhood',
+
+        '`I like my community a lot. It is in a good area with lots of walking paths and nobody is too loud in the '
+        'apartments near me. `': {
+
+            '#UNX': {'#GRET': 'exit'}
+        }
+    }
 }
 
 update_rules = {
