@@ -72,23 +72,27 @@ system = {
                                 '<#AGREE, #TOKLIMIT(1)>': {
                                     'state': 'clubs_question_yes',
 
-                                    '`Awesome! What are you a part of?`': {
+                                    '`Awesome! What are you a part of?`'
+                                    '#GSRET(exit)': {
                                         'state': 'club_part_of_q',
 
                                         '[{club,organization,society}]':{
                                             'state': 'unknown_club',
 
-                                            '`That sounds interesting. What do you do for it?`': 'ask_about_club'
+                                            '`That sounds interesting. What do you do for it?`'
+                                            '#GSRET(exit)':
+                                                'ask_about_club'
                                         },
 
                                         '[$club=#ONT(_school club)]':{
                                             'state': 'known_club',
                                             'score': 1.1,
 
-                                            '`Cool! Your school has a group for ` $club `? What is it like?`': {
+                                            '`Cool! Your school has a group for ` $club `? What is it like?`'
+                                            '#GSRET(exit)': {
                                                 'state': 'ask_about_club',
 
-                                                '#UNX(Sounds like a good time! )': 'exit'
+                                                '#UNX(Sounds like a good time!)': 'exit'
                                             }
                                         },
 
@@ -100,7 +104,8 @@ system = {
                                     'state': 'clubs_question_no',
 
                                     '`Me neither. I think I\'d rather just hang out with friends or '
-                                    'spend some time by myself most days.`': {
+                                    'spend some time by myself most days.`'
+                                    '#GSRET(exit)': {
 
                                         '#UNX': 'exit'
                                     }
@@ -117,7 +122,8 @@ system = {
                                     'state': 'clubs_dumb',
 
                                     '`You think school clubs are ` $thinks_of_clubs `? I wasn\'t expecting that. I\'m '
-                                    'not in any either, but I think they are good for a lot of people still. `': {
+                                    'not in any either, but I think they are good for a lot of people still. `'
+                                    '#GSRET(exit)': {
 
                                         '#UNX': 'exit'
                                     }
@@ -198,7 +204,31 @@ system = {
             'state': 'user_not_student'
         },
 
-        '#UNX': {
+        '[#NOT(not),{college,university}]'
+        '#SET($is_student=True,$in_college=True)':{
+            'state': 'user_is_student',
+            'score': 1.1
+        },
+
+        '[#NOT(not),{high school,high schooler}]'
+        '#SET($is_student=True,$in_high_school=True)': {
+            'state': 'user_is_student',
+            'score': 1.1
+        },
+
+        '[#NOT(not),{middle school,middle schooler,[!{sixth,seventh,eighth} grader],[!{sixth,seventh,eighth} grade]}]'
+        '#SET($is_student=True,$in_middle_school=True)': {
+            'state': 'user_is_student',
+            'score': 1.1
+        },
+
+        '[#NOT(not),{elementary school,elementary schooler,[!{first,second,third,fourth,fifth} grader],[!{first,second,third,fourth,fifth} grade]}]'
+        '#SET($is_student=True,$in_elementary_school=True)': {
+            'state': 'user_is_student',
+            'score': 1.1
+        },
+
+        '#UNX(Okay)': {
             'score': 0.8,
             'state': 'exit'
         }
@@ -317,7 +347,8 @@ user = {
     #name of school, where you go to school
     '{'
     '<{name,title,call},{you,your},school>,'
-    '[where,{you,your},school]'
+    '[where,{you,your},school],'
+    '[what,school,you,go]'
     '}': {
         'state': 'school_name_q',
 
@@ -397,7 +428,8 @@ user = {
     #what is school like
     '{'
     '[what,your,#LEM(school,class,course),like],'
-    '[{tell me about,tell me more,describe,explain},your,#LEM(school,class,course)]'
+    '[{tell me about,tell me more,describe,explain},your,#LEM(school,class,course)],'
+    '[what,do,you,do,school]'
     '}': {
         'state': 'describe_school_q',
 
@@ -511,6 +543,18 @@ user = {
 
             '#UNX': {'#GRET': 'exit', 'state': 'school_hard_unx'}
         }
+    },
+
+    #What do you study
+    '[what,{your,you},{study,major,field,degree}]':{
+        'state': 'school_major_q',
+
+        '`I don\'t really have a specific focus in school right now. I am just getting started, so I am taking '
+        'some introductory courses in things like Math and History.`': {
+            'state': 'school_major',
+
+            '#UNX': {'#GRET': 'exit', 'state': 'school_major_unx'}
+        }
     }
 }
 
